@@ -4,9 +4,9 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/operator-framework/operator-metering/pkg/db"
-	"github.com/operator-framework/operator-metering/pkg/hive"
-	"github.com/operator-framework/operator-metering/pkg/presto"
+	"github.com/kube-reporting/metering-operator/pkg/db"
+	"github.com/kube-reporting/metering-operator/pkg/hive"
+	"github.com/kube-reporting/metering-operator/pkg/presto"
 )
 
 type HiveTableManager interface {
